@@ -2,7 +2,7 @@
  * Enhanced Seccomp Architecture/Machine Specific Code
  *
  * Copyright (c) 2012 Red Hat <pmoore@redhat.com>
- * Author: Paul Moore <pmoore@redhat.com>
+ * Author: Paul Moore <paul@paul-moore.com>
  */
 
 /*
@@ -30,9 +30,12 @@
 
 #include "system.h"
 
+struct db_filter;
 struct db_api_arg;
+struct db_api_rule_list;
 
 struct arch_def {
+	/* arch definition */
 	uint32_t token;
 	uint32_t token_bpf;
 	enum {
@@ -45,6 +48,13 @@ struct arch_def {
 		ARCH_ENDIAN_LITTLE,
 		ARCH_ENDIAN_BIG,
 	} endian;
+
+	/* arch specific functions */
+	int (*syscall_resolve_name)(const char *name);
+	const char *(*syscall_resolve_num)(int num);
+	int (*syscall_rewrite)(int *syscall);
+	int (*rule_add)(struct db_filter_col *col, struct db_filter *db,
+			bool strict, struct db_api_rule_list *rule);
 };
 
 /* arch_def for the current architecture */
@@ -90,10 +100,10 @@ int arch_syscall_resolve_name(const struct arch_def *arch, const char *name);
 const char *arch_syscall_resolve_num(const struct arch_def *arch, int num);
 
 int arch_syscall_translate(const struct arch_def *arch, int *syscall);
-int arch_syscall_rewrite(const struct arch_def *arch, bool strict,
-			 int *syscall);
+int arch_syscall_rewrite(const struct arch_def *arch, int *syscall);
 
-int arch_filter_rewrite(const struct arch_def *arch,
-			bool strict, int *syscall, struct db_api_arg *chain);
+int arch_filter_rule_add(struct db_filter_col *col, struct db_filter *db,
+			 bool strict, uint32_t action, int syscall,
+			 unsigned int chain_len, struct db_api_arg *chain);
 
 #endif
